Change log
==========

4.0b1 (2017-09-18)
------------------

* Move all the code to the ``Zope`` package. Making this package a placeholder.

Older releases see https://pypi.org/project/Zope2/#history
